@@ -6,22 +6,22 @@ from pccm.core import (ConstructorMeta, DestructorMeta, ExternalFunctionMeta,
 
 class CudaMemberFunctionMeta(MemberFunctionMeta):
     def is_header_only(self):
-        return self.inline or "__forceinline__" in self.attrs
+        return super().is_header_only() or "__forceinline__" in self.attrs
 
 
 class CudaStaticMemberFunctionMeta(StaticMemberFunctionMeta):
     def is_header_only(self):
-        return self.inline or "__forceinline__" in self.attrs
+        return super().is_header_only() or "__forceinline__" in self.attrs
 
 
 class CudaConstructorMeta(ConstructorMeta):
     def is_header_only(self):
-        return self.inline or "__forceinline__" in self.attrs
+        return super().is_header_only() or "__forceinline__" in self.attrs
 
 
 class CudaDestructorMeta(DestructorMeta):
     def is_header_only(self):
-        return self.inline or "__forceinline__" in self.attrs
+        return super().is_header_only() or "__forceinline__" in self.attrs
 
 
 class CudaExternalFunctionMeta(ExternalFunctionMeta):
@@ -32,6 +32,7 @@ class CudaExternalFunctionMeta(ExternalFunctionMeta):
 def cuda_global_function(func=None,
                          inline: bool = False,
                          attrs: Optional[List[str]] = None,
+                         macro_guard: Optional[str] = None,
                          impl_loc: str = "",
                          impl_file_suffix: str = ".cu",
                          name=None):
@@ -42,6 +43,7 @@ def cuda_global_function(func=None,
                                      name=name,
                                      inline=inline,
                                      constexpr=False,
+                                     macro_guard=macro_guard,
                                      impl_loc=impl_loc,
                                      impl_file_suffix=impl_file_suffix,
                                      attrs=cuda_global_attrs)
@@ -55,6 +57,7 @@ def member_function(func=None,
                     constexpr: bool = False,
                     const: bool = False,
                     attrs: Optional[List[str]] = None,
+                    macro_guard: Optional[str] = None,
                     impl_loc: str = "",
                     impl_file_suffix: str = ".cu",
                     name=None):
@@ -77,6 +80,7 @@ def member_function(func=None,
                                   override=False,
                                   final=False,
                                   const=const,
+                                  macro_guard=macro_guard,
                                   impl_loc=impl_loc,
                                   impl_file_suffix=impl_file_suffix,
                                   attrs=attrs)
@@ -90,6 +94,7 @@ def static_function(func=None,
                     forceinline: bool = False,
                     constexpr: bool = False,
                     attrs: Optional[List[str]] = None,
+                    macro_guard: Optional[str] = None,
                     impl_loc: str = "",
                     impl_file_suffix: str = ".cu",
                     name=None):
@@ -110,6 +115,7 @@ def static_function(func=None,
         inline=inline,
         constexpr=constexpr,
         attrs=attrs,
+        macro_guard=macro_guard,
         impl_loc=impl_loc,
         impl_file_suffix=impl_file_suffix,
     )
@@ -123,6 +129,7 @@ def external_function(func=None,
                       forceinline: bool = False,
                       constexpr: bool = False,
                       attrs: Optional[List[str]] = None,
+                      macro_guard: Optional[str] = None,
                       impl_loc: str = "",
                       impl_file_suffix: str = ".cu",
                       name=None):
@@ -143,6 +150,7 @@ def external_function(func=None,
         inline=inline,
         constexpr=constexpr,
         attrs=attrs,
+        macro_guard=macro_guard,
         impl_loc=impl_loc,
         impl_file_suffix=impl_file_suffix,
     )
@@ -156,6 +164,7 @@ def constructor(func=None,
                 forceinline: bool = False,
                 constexpr: bool = False,
                 attrs: Optional[List[str]] = None,
+                macro_guard: Optional[str] = None,
                 impl_loc: str = "",
                 impl_file_suffix: str = ".cu",
                 name=None):
@@ -175,6 +184,7 @@ def constructor(func=None,
         inline=inline,
         constexpr=constexpr,
         attrs=attrs,
+        macro_guard=macro_guard,
         impl_loc=impl_loc,
         impl_file_suffix=impl_file_suffix,
     )
